@@ -423,7 +423,7 @@ class ServerOptions(Options):
         self.add("nodaemon", "supervisord.nodaemon", "n", "nodaemon", flag=1,
                  default=0)
         self.add("delaysecs", "supervisord.delaysecs", "p",
-                 "delaysecs", default=0.2)
+                 "delaysecs", default=0.5)
         self.add("user", "supervisord.user", "u:", "user=")
         self.add("umask", "supervisord.umask", "m:", "umask=",
                  octal_type, default='022')
@@ -627,7 +627,7 @@ class ServerOptions(Options):
         section.pidfile = existing_dirpath(get('pidfile', 'supervisord.pid'))
         section.identifier = get('identifier', 'supervisor')
         section.nodaemon = boolean(get('nodaemon', 'false'))
-        section.delaysecs = float(get("delaysecs", 0.2))
+        section.delaysecs = float(get("delaysecs", 0.5))
         section.silent = boolean(get('silent', 'false'))
 
         tempdir = tempfile.gettempdir()
@@ -895,7 +895,7 @@ class ServerOptions(Options):
 
         for process_num in range(numprocs_start, numprocs + numprocs_start):
             expansions = common_expansions
-            expansions.update({'process_num': process_num})
+            expansions.update({'process_num': process_num, 'numprocs': numprocs})
             expansions.update(self.environ_expansions)
 
             environment = dict_of_key_value_pairs(
@@ -1156,7 +1156,14 @@ class ServerOptions(Options):
         pass
 
     def kill(self, pid, sig):
-        self.pidhistory[pid].process.send_signal(sig)
+        try:
+            subprocess = self.pidhistory[pid]
+        except KeyError:
+            subprocess = self.pidhistory[abs(pid)]
+        output = subprocess.process.kill2(sig, pid < 0)
+        if output:
+            for loutput in output.split('\n'):
+                self.logger.info(loutput)
 
     def set_uid_or_exit(self):
         if self.uid is None:
